"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.consoleUserInterface = void 0;
const chalk_1 = __importDefault(require("chalk"));
const log_symbols_1 = __importDefault(require("log-symbols"));
const ivrTranscription = (callServer, testInstance) => {
    let includeTestName = false;
    let totalTests = 0;
    callServer.on("testStarted", () => {
        totalTests++;
        if (totalTests >= 2) {
            includeTestName = true;
        }
    });
    testInstance.on("progress", (event) => {
        const state = chalk_1.default.gray.bold(
        // event.transcription.isFinal ? "Finished: " :
        "Transcribing: ");
        const testName = includeTestName ? `${event.test.name}: ` : "";
        console.log(state + chalk_1.default.gray(`${testName}${event.transcription.transcription}`));
    });
};
const ivrTestPassed = (emitter) => emitter.on("testPassed", (event) => console.log(log_symbols_1.default.success, chalk_1.default.green(`Test Complete: ${event.test.name}...`)));
const ivrTestFailed = (testInstance) => testInstance.on("testFailed", (event) => {
    console.log(`${chalk_1.default.bold.blue("Test -")} ${chalk_1.default.bold.blue(event.test.name)}\n`, `Them: "${event.transcription}"\n`, chalk_1.default.red("No condition matched this transcript\n"));
    console.log(log_symbols_1.default.error, chalk_1.default.bold.red(`Test Failed`));
});
const callConnected = (callServer) => {
    callServer.on("callConnected", () => {
        console.log("Call connected");
    });
};
const callServerListening = (callServer) => {
    callServer.on("listening", ({ localUrl }) => {
        // const { port } = localUrl.port.address() as AddressInfo;
        console.log(`Server is listening on ${localUrl.port} for the stream for the call`);
    });
};
const callServerStopped = (callServer) => {
    callServer.on("stopped", () => console.log("The server has closed"));
};
const callServerErrored = (callServer) => {
    callServer.on("error", (event) => console.error("Server experienced an error", event.error.message));
};
const callRequested = (emitter) => emitter.on("callRequested", (event) => {
    switch (event.requestedCall.type) {
        case "audio-playback":
            console.log("Playing back audio to simulate call");
            break;
        case "telephony":
            console.log(`Calling ${event.requestedCall.call.to}...`);
            break;
    }
});
const callRequestErrored = (emitter) => emitter.on("callRequestErrored", (event) => console.error(`Call failed`, event.error.message));
const ivrTestConditionMet = (callServer, testInstance) => {
    let includeTestName = false;
    let totalTests = 0;
    callServer.on("testStarted", () => {
        totalTests++;
        if (totalTests >= 2) {
            includeTestName = true;
        }
    });
    testInstance.on("conditionMet", (event) => {
        const lines = [];
        if (includeTestName) {
            lines.push(`Test - ${event.test.name}`);
        }
        lines.push(`Them: "${event.transcription}"`);
        lines.push(`You: ${event.condition.then.describe()}`);
        console.log(chalk_1.default.bold.blue(lines.join(`\n`)));
    });
};
const callServerStarted = (eventEmitter) => {
    eventEmitter.on("callServerStarted", ({ callServer }) => {
        callConnected(callServer);
        callServerListening(callServer);
        callServerStopped(callServer);
        callServerErrored(callServer);
        callServer.on("testStarted", ({ testInstance }) => {
            console.log(`Call using test '${testInstance.getTest().name}'`);
            ivrTestPassed(testInstance);
            ivrTestFailed(testInstance);
            ivrTestConditionMet(callServer, testInstance);
            ivrTranscription(callServer, testInstance);
        });
    });
};
const consoleUserInterface = () => ({
    initialise(eventEmitter) {
        callServerStarted(eventEmitter);
        callRequested(eventEmitter);
        callRequestErrored(eventEmitter);
    },
    timedOut(reason) {
        console.log(chalk_1.default.bold.red(`Timed out: ${reason}`));
    },
});
exports.consoleUserInterface = consoleUserInterface;
